package org.eclipse.corona.mylar;

import java.util.List;
import java.util.Collection;
import java.util.Iterator;

import org.eclipse.mylar.context.core.ContextCorePlugin;
import org.eclipse.mylar.context.core.IMylarContextListener;
import org.eclipse.mylar.context.core.IMylarContext;
import org.eclipse.mylar.context.core.IMylarElement;
import org.eclipse.mylar.internal.context.core.MylarContextRelation;
import org.eclipse.mylar.internal.context.core.MylarContextManager;

public class ContextListeners implements IMylarContextListener
{
	public ContextListeners()
	{
		//
		//	Get contect manager
		//
		MylarContextManager contextManager = ContextCorePlugin.getContextManager();
		
		//
		//	Add listeners
		//
		if (contextManager != null)
		{
			contextManager.addActivityMetaContextListener(this);
			contextManager.addListener(this);
			System.out.println("Mylar listeners added.");
		}

	}
	
	public void remove()
	{
		//
		//	Get contect manager
		//
		MylarContextManager contextManager = ContextCorePlugin.getContextManager();
		
		//
		//	removelisteners
		//
		if (contextManager != null)
		{
			contextManager.removeActivityMetaContextListener(this);
			contextManager.removeListener(this);
			System.out.println("Mylar listeners removed.");
		}

		
	}
	
	public void contextActivated(IMylarContext context)
	{
		String contextName = context.toString();
		IMylarElement activeNode = context.getActiveNode();
		if (activeNode != null)
		{
			String elementName = activeNode.getHandleIdentifier();
			System.out.println("activating context:" + contextName + " " + elementName);
			
		}
		else
		{
			System.out.println("activating context:" + contextName);
		}
	}

	public void contextDeactivated(IMylarContext context)
	{
		String contextName = context.toString();
		IMylarElement activeNode = context.getActiveNode();
		if (activeNode != null)
		{
			String elementName = activeNode.getHandleIdentifier();
			System.out.println("deactivating context:" + contextName + " " + elementName);
			
		}
		else
		{
			System.out.println("deactivating context:" + contextName);
		}
	}

	/**
	 * E.g. highlighters or scaling factors are being actively modified (for
	 * active updating).
	 * 
	 * @param kind
	 *            TODO
	 */
	public void presentationSettingsChanging(UpdateKind kind)
	{
		System.out.println("presentationSettingsChanging");
	}

	/**
	 * Modification completed (for slow updating).
	 * 
	 * @param kind
	 *            TODO
	 */
	public void presentationSettingsChanged(UpdateKind kind)
	{
		System.out.println("presentationSettingsChanged");
	}

	/**
	 * Called when the interest level for multiple elements changes, sorted
	 * according to the containment hierarchy. The last element is the element
	 * invoking the change.
	 */
	public void interestChanged(List<IMylarElement> elements)
	{
		System.out.println("interestChanged");
		for (int idx = 0; idx < elements.size(); idx ++)
		{
			IMylarElement element = elements.get(idx);
			System.out.println("interestChanged: " + element.getHandleIdentifier());
			Collection relations = element.getRelations();
			Iterator iter = relations.iterator();
			while (iter.hasNext())
			{
				
				Object obj = iter.next();
				if (obj instanceof MylarContextRelation)
				{
					MylarContextRelation relation = (MylarContextRelation)obj;
					System.out.println("Relation: " + relation.getContentType() + " - " + relation.toString());
				}
			}
		}
	}

	/**
	 * @param newLandmarks
	 *            list of IJavaElement(s)
	 */
	public void landmarkAdded(IMylarElement element)
	{
		System.out.println("landmarkAdded: " + element.getHandleIdentifier());
	}

	/**
	 * @param newLandmarks
	 *            list of IJavaElement(s)
	 */
	public void landmarkRemoved(IMylarElement element)
	{
		System.out.println("landmarkRemoved: " + element.getHandleIdentifier());
	}

	public void elementDeleted(IMylarElement element)
	{
		System.out.println("elementDeleted: " + element.getHandleIdentifier());
	}
	
	public void relationsChanged(IMylarElement element)
	{
		System.out.println("relationsChanged: " + element.getHandleIdentifier());
	}

}
